---
feature_story: FS_93_18_57_91
feature_title: client fail over to redundant servers
feature_status: TEST
---

keywords: client-side fail over, redundant servers

This feature is for client-side fail-over to other configured redundant servers.

It uses `@/var/argrelay_client.server_index` state file
to select one of the several configured server connection.

If connection fails, it selects (round-robin) next connection.

# High-level logic

*   Read the state with the CURR latest online server.
    *   If none, read client config for the first server.
*   Read config with ALL configured servers.
*   Loop through a ring of ALL configured servers starting with the selected one.
    *   If data retrieval succeeds, store the current server as the latest online server. Exit.
    *   If data retrieval fails, select the next server to try.
    *   If the ring is over, fail.

